###

    Build Log

    Build started: Project: clibutils, Configuration: Debug|Win32

    Command Lines
      Creating temporary file "d:\Avinash\work\clibutils\win\clibutils_Debug\RSP00001531481252.rsp" with contents
    [
    /Od /I "..\inc" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_UNICODE" /D "UNICODE" /Gm /EHsc /RTC1 /MDd /Fo"clibutils_Debug\\" /Fd"clibutils_Debug\clibutils.pdb" /W3 /c /Wp64 /ZI /TC ..\src\c_deque.c
    ]
    Creating command line "cl.exe @d:\Avinash\work\clibutils\win\clibutils_Debug\RSP00001531481252.rsp /nologo /errorReport:prompt"
    Creating temporary file "d:\Avinash\work\clibutils\win\clibutils_Debug\RSP00001631481252.rsp" with contents
    [
    /OUT:"D:\Avinash\work\clibutils\win\clibutils_Debug\clibutils.lib" .\clibutils_Debug\c_array.obj

    .\clibutils_Debug\c_deque.obj

    .\clibutils_Debug\c_heap.obj

    .\clibutils_Debug\c_map.obj

    .\clibutils_Debug\c_rb.obj

    .\clibutils_Debug\c_set.obj

    .\clibutils_Debug\c_slist.obj

    .\clibutils_Debug\c_stack.obj

    .\clibutils_Debug\c_util.obj
    ]
    Creating command line "lib.exe @d:\Avinash\work\clibutils\win\clibutils_Debug\RSP00001631481252.rsp /NOLOGO"

    Output Window
      Compiling...
    c_deque.c
    Creating library...

    Results
      Build log was saved at "file://d:\Avinash\work\clibutils\win\clibutils_Debug\BuildLog.htm"
    clibutils - 0 error(s), 0 warning(s)